@@ -1,3 +1,10 @@
+# This file is a part of the AnyBlok / Pyramid project
+#
+#    Copyright (C) 2002 Pierre Verkest <pierreverkest84@gmail.com>
+#
+# This Source Code Form is subject to the terms of the Mozilla Public License,
+# v. 2.0. If a copy of the MPL was not distributed with this file,You can
+# obtain one at http://mozilla.org/MPL/2.0/.
 from pyramid.view import view_config, view_defaults
 from anyblok_pyramid import current_blok
 
@@ -11,7 +18,11 @@ class Bloks:
     @view_config(route_name='bloks', renderer="json",
                  request_method='GET', permission="read")
     def get_all(self):
-        bloks = self.registry.System.Blok.query().all()
+        query = self.registry.Pyramid.restrict_query_by_user(
+            self.registry.System.Blok.query(),
+            self.request.authenticated_userid
+        )
+        bloks = query.all()
         return bloks.to_dict('name', 'author', 'version')
 
     @view_config(route_name='blok', renderer="json",
